==> linuxconf_1.17r5.orig.tar.gz: linuxconf-1.17r5/modules/wuftpd/wuftpd.m <==
extern const char **_dictionary_wuftpd;
#ifndef DICTIONARY_REQUEST
	#define DICTIONARY_REQUEST \
	const char **_dictionary_wuftpd;\
	TRANSLATE_SYSTEM_REQ _dictionary_req_wuftpd("wuftpd",_dictionary_wuftpd,45,0);\
	void dummy_dict_wuftpd(){}
#endif
#ifndef MSG_U
	#define MSG_U(id,m)	_dictionary_wuftpd[id]
	#define MSG_B(id,m,n)	_dictionary_wuftpd[id]
	#define MSG_R(id)	_dictionary_wuftpd[id]
	#define P_MSG_U(id,m)	new_trans_notload(_dictionary_wuftpd,id)
	#define P_MSG_B(id,m,n)	new_trans_notload(_dictionary_wuftpd,id)
	#define P_MSG_R(id)	new_trans_notload(_dictionary_wuftpd,id)
#endif
#define M_wuftpd	0
#define T_USAGE	1
#define T_BASE	2
#define T_FTPCONF	3
#define T_EMAIL	4
#define F_ADDR	5
#define F_ROOT	6
#define F_BANNER	7
#define F_LOGFILE	8
#define I_DELREC	9
#define H_VIRTUALS	10
#define T_VIRTUALS	11
#define I_ADMINTREES	12
#define T_ONEVIRTUAL	13
#define T_FTPBASECONF	14
#define M_BASIC	15
#define M_VIRTUAL	16
#define I_COMPRESS	17
#define I_TAR	18
#define I_CHMOD	19
#define I_DELETE	20
#define I_OVERWRITE	21
#define T_RENAME	22
#define I_LOGINBOUND	23
#define I_LOGOUTBOUND	24
#define N_MISC	25
#define T_MISC	26
#define T_GUESTGROUP	27
#define T_BANNER	28
#define N_ACCESSCTRL	29
#define T_ACCESSCTRL	30
#define T_REALUSERS	31
#define T_GUESTUSERS	32
#define T_ANONYMOUS	33
#define T_SHUTDOWN	34
#define M_WUFTPD	35
#define I_NEWROOTDIR	36
#define T_NEWROOTDIR	37
#define T_MVIRTUAL	38
#define E_VHOSTEXIST	39
#define E_HOSTEXIST	40
#define E_IVLDOPT	41
#define E_MISSING	42
#define E_NOROOT	43
#define E_NOANONYMOUSDIR	44

==> linuxconf_1.26r4.orig.tar.gz: linuxconf-1.26r4/modules/wuftpd/wuftpd.m <==
extern const char **_dictionary_wuftpd;
#ifndef DICTIONARY_REQUEST
	#define DICTIONARY_REQUEST \
	const char **_dictionary_wuftpd;\
	TRANSLATE_SYSTEM_REQ _dictionary_req_wuftpd("wuftpd",_dictionary_wuftpd,77,0);\
	void dummy_dict_wuftpd(){}
#endif
#ifndef MSG_U
	#define MSG_U(id,m)	_dictionary_wuftpd[id]
	#define MSG_B(id,m,n)	_dictionary_wuftpd[id]
	#define MSG_R(id)	_dictionary_wuftpd[id]
	#define P_MSG_U(id,m)	new_trans_notload(_dictionary_wuftpd,id)
	#define P_MSG_B(id,m,n)	new_trans_notload(_dictionary_wuftpd,id)
	#define P_MSG_R(id)	new_trans_notload(_dictionary_wuftpd,id)
#endif
#define M_wuftpd	0
#define T_USAGE	1
#define T_BASE	2
#define T_FTPCONF	3
#define T_EMAIL	4
#define F_ADDR	5
#define F_ROOT	6
#define F_BANNER	7
#define F_LOGFILE	8
#define I_DELREC	9
#define H_VIRTUALS	10
#define T_VIRTUALS	11
#define I_ADMINTREES	12
#define T_ONEVIRTUAL	13
#define T_FTPBASECONF	14
#define M_BASIC	15
#define M_VIRTUAL	16
#define I_COMPRESS	17
#define I_TAR	18
#define I_CHMOD	19
#define I_DELETE	20
#define I_OVERWRITE	21
#define T_RENAME	22
#define I_LOGINBOUND	23
#define I_LOGOUTBOUND	24
#define N_MISC	25
#define T_MISC	26
#define T_GUESTGROUP	27
#define T_BANNER	28
#define N_ACCESSCTRL	29
#define T_ACCESSCTRL	30
#define T_REALUSERS	31
#define T_GUESTUSERS	32
#define T_ANONYMOUS	33
#define T_SHUTDOWN	34
#define M_WUFTPD	35
#define I_NEWROOTDIR	36
#define T_NEWROOTDIR	37
#define T_MVIRTUAL	38
#define E_VHOSTEXIST	39
#define E_HOSTEXIST	40
#define E_IVLDOPT	41
#define E_MISSING	42
#define E_NOROOT	43
#define E_NOANONYMOUSDIR	44
#define I_ALLOWANON	45
#define N_TIMEOUTS	46
#define T_TIMEOUTS	47
#define F_ACCEPT	48
#define F_CONNECT	49
#define F_DATA	50
#define F_IDLE	51
#define F_MAXIDLE	52
#define F_IDENT	53
#define I_DEFAULT	54
#define M_LOGS	55
#define T_FTPLOGS	56
#define H_FTPLOGS	57
#define I_MAINSERVER	58
#define T_HOSTFTPLOGS	59
#define I_FTPLOGS	60
#define I_OUTPUTCMD	61
#define N_NOLOGFORHOST	62
#define P_VIEWLOG	63
#define E_NOGROUP	64
#define E_NOBANNERFILE	65
#define P_EDITBANNER	66
#define T_BANNERFILE	67
#define B_EDITBANNER	68
#define T_LOGDETAILS	69
#define H_LOGDETAILS	70
#define B_VIEWSTATS	71
#define I_DOWNLOAD	72
#define I_UPLOAD	73
#define I_ANONYMOUS	74
#define I_GUEST	75
#define I_USER	76
